@@ -664,7 +664,7 @@ class Groups(object):
 			raise Exception('Both graph_id and graph_name can\'t be none when graph object has no \'name\' or \'id\' attribute!')
 
 		if graph_id is None:
-			graph = self.get_graph(graph_name=graph_name)
+			graph = self.client.get_graph(graph_name=graph_name)
 			if graph is None or graph.id is None:
 				raise Exception('Graph with name `%s` doesnt exist for user `%s`!' % (graph_name, self.client.username))
 			else:
@@ -756,7 +756,7 @@ class Groups(object):
 			raise Exception('Both graph_id and graph_name can\'t be none when graph object has no \'name\' or \'id\' attribute!')
 
 		if graph_id is None:
-			graph = self.get_graph(graph_name=graph_name)
+			graph = self.client.get_graph(graph_name=graph_name)
 			if graph is None or graph.id is None:
 				raise Exception('Graph with name `%s` doesnt exist for user `%s`!' % (graph_name, self.client.username))
 			else:
